==> media_proxy-tomato.20190119.070234-50-sources.jar: com/jz/jar/media/proxy/PlaylistProxy.java <==
package com.jz.jar.media.proxy;

import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.context.annotation.Lazy;
import org.springframework.stereotype.Service;

import com.google.common.collect.Lists;
import com.google.common.collect.Maps;
import com.jz.common.utils.collection.ArrayMapTools;
import com.jz.common.utils.text.StringTools;
import com.jz.jar.media.common.ItemCard;
import com.jz.jar.media.enums.BrandEnum;
import com.jz.jar.media.request.NextPlayVideoRequest;
import com.jz.jar.media.request.PlaylistRequest;
import com.jz.jar.media.service.PlaylistPicsService;
import com.jz.jar.media.service.PlaylistService;
import com.jz.jar.media.service.UserCollectService;
import com.jz.jar.media.tool.AliyunBean;
import com.jz.jar.media.tool.PictureCompress;
import com.jz.jar.media.wrapper.PlaylistWrapper;
import com.jz.jar.media.wrapper.VideoWrapper;
import com.jz.jooq.media.tables.pojos.Playlist;
import com.jz.jooq.media.tables.pojos.PlaylistPics;

@Lazy
@Service
public class PlaylistProxy {

	@Autowired
	private PlaylistService playlistService;
	@Autowired
	private PlaylistPicsService playlistPicsService;
	@Autowired
	private UserCollectService userCollectService;
	@Autowired
	private PlaylistVideoProxy playlistVideoProxy;
	
	private Map<String, String> getPlaylistPics(List<PlaylistPics> pics) {
		if (ArrayMapTools.isEmpty(pics))
			return null;
		Map<String, String> has = Maps.newHashMap();
		pics.forEach(it -> {
			// 数字不能直接作为变量，所以使用literal
			has.put(it.getSize().getLiteral(), AliyunBean.getImagesUrl(it.getUrl(), PictureCompress._60));
		});
		return has;
	}
	
	public PlaylistWrapper getSinglePlaylist(PlaylistRequest req, BrandEnum brand) {
		Playlist pl = playlistService.getOnlinePlaylist(req.getPid(), brand);
		if (null == pl)
			return null;
		PlaylistWrapper wp = PlaylistWrapper.of(pl);
		// 专辑图片
		wp.setPics(getPlaylistPics(playlistPicsService.getPics(req.getPid())));
		boolean isCollectPlaylist = false;
		// playabc 才有专辑的收藏
		if (brand == BrandEnum.playabc) {
			if (StringTools.isNotEmpty(req.getUid())) {
				isCollectPlaylist = userCollectService.isCollect(req.getUid(), req.getPid());
			}
			wp.setIsCollect(isCollectPlaylist);
		}
		// 获取下一个需要播放的视频
		if (req.getWithNextVideo()) {
			wp.setVideo(playlistVideoProxy.getNextPlayVideoForHistory(req.getUid(), pl.getPid(), pl.getWid(), brand));
		}
		return wp;
	}

	public List<PlaylistWrapper> getMultiPlaylist(PlaylistRequest req, BrandEnum brand) {
		List<Playlist> playlistArray = playlistService.getOnlinePlaylist(req.getPids(), brand);
		if (ArrayMapTools.isEmpty(playlistArray))
			return null;
		List<String> collectPlaylist = null;
		if (brand == BrandEnum.playabc) { // 获取已经收藏的专辑
			if (null == req.getIsCollect() && StringTools.isNotEmptyAndBlank(req.getUid()))
				collectPlaylist = userCollectService.getExistCollect(req.getUid(), req.getPids());
			if (null == collectPlaylist)
				collectPlaylist = Lists.newArrayList();
		}
		// 专辑图片
		Map<String, List<PlaylistPics>> pid2Pics = playlistPicsService.getPicsHas(req.getPids());
		
		// 下一个需要播放的视频
		Map<String, VideoWrapper> pid2VideoCard = null;
		if (req.getWithNextVideo()) {
			NextPlayVideoRequest nextRequest = NextPlayVideoRequest.of(req.getUid(), req.getSuid(), playlistArray);
			nextRequest.setIsSpecial(req.getIsSpecial()).setIsEverday(req.getIsEverday());
			pid2VideoCard = playlistVideoProxy.getNextPlayVideoForHistory(nextRequest);
		} else
			pid2VideoCard = Maps.newHashMap();

		List<PlaylistWrapper> wrappers = Lists.newArrayList();
		PlaylistWrapper wp = null;
		for (Playlist pl : playlistArray) {
			wp = PlaylistWrapper.of(pl);
			wp.setPics(this.getPlaylistPics(pid2Pics.get(pl.getPid())));
			if (null != req.getIsCollect()) {
				wp.setIsCollect(req.getIsCollect());
			} else if (null != collectPlaylist) {
				wp.setIsCollect(collectPlaylist.contains(pl.getPid()));
			}
			if (null != req.getIsRecomm()) {
				wp.setIsRecomm(req.getIsRecomm());
			}
			wp.setVideo(pid2VideoCard.get(pl.getPid()));
			wrappers.add(wp);
		}
		return wrappers;
	}
	
	public Map<String, PlaylistWrapper> getMultiPlaylistHas(PlaylistRequest req, BrandEnum brand) {
		List<PlaylistWrapper> playlists = this.getMultiPlaylist(req, brand);
		if (ArrayMapTools.isEmpty(playlists))
			return Maps.newHashMap();
		Map<String, PlaylistWrapper> pid2Instance = Maps.newLinkedHashMap();
		playlists.forEach(it -> pid2Instance.put(it.getPid(), it));
		return pid2Instance;
	}
	
	public List<ItemCard> getMultiPlaylistCards(PlaylistRequest req, BrandEnum brand) {
		List<PlaylistWrapper> wrappers = this.getMultiPlaylist(req, brand);
		if (null == wrappers)
			return null;
		return wrappers.stream().map(ItemCard::of).collect(Collectors.toList());
	}
	
	public Map<String, ItemCard> getMultiPlaylistCardHas(PlaylistRequest req, BrandEnum brand) {
		List<ItemCard> cards = this.getMultiPlaylistCards(req, brand);
		if (ArrayMapTools.isEmpty(cards))
			return Maps.newHashMap();
		Map<String, ItemCard> pid2Card = Maps.newLinkedHashMap();
		cards.forEach(it-> pid2Card.put(it.getPlaylist().getPid(), it));
		return pid2Card;
	}
}

==> media_proxy-tomato.20190121.035220-57-sources.jar: com/jz/jar/media/proxy/PlaylistProxy.java <==
package com.jz.jar.media.proxy;

import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.context.annotation.Lazy;
import org.springframework.stereotype.Service;

import com.google.common.collect.Lists;
import com.google.common.collect.Maps;
import com.jz.common.utils.collection.ArrayMapTools;
import com.jz.common.utils.text.StringTools;
import com.jz.jar.media.common.ItemCard;
import com.jz.jar.media.enums.BrandEnum;
import com.jz.jar.media.request.NextPlayVideoRequest;
import com.jz.jar.media.request.PlaylistRequest;
import com.jz.jar.media.service.PlaylistPicsService;
import com.jz.jar.media.service.PlaylistService;
import com.jz.jar.media.service.UserCollectService;
import com.jz.jar.media.tool.AliyunBean;
import com.jz.jar.media.tool.PictureCompress;
import com.jz.jar.media.wrapper.PlaylistWrapper;
import com.jz.jar.media.wrapper.VideoWrapper;
import com.jz.jooq.media.tables.pojos.Playlist;
import com.jz.jooq.media.tables.pojos.PlaylistPics;

@Lazy
@Service
public class PlaylistProxy {

	@Autowired
	private PlaylistService playlistService;
	@Autowired
	private PlaylistPicsService playlistPicsService;
	@Autowired
	private UserCollectService userCollectService;
	@Autowired
	private PlaylistVideoProxy playlistVideoProxy;
	
	private Map<String, String> getPlaylistPics(List<PlaylistPics> pics, BrandEnum brand) {
		if (ArrayMapTools.isEmpty(pics))
			return null;
		PictureCompress compress = PictureCompress._510x280;
		if (brand == BrandEnum.tomato)
			compress = PictureCompress._60;
		Map<String, String> has = Maps.newHashMap();
		for (PlaylistPics ps : pics) {
			has.put(ps.getSize().getLiteral(), AliyunBean.getImagesUrl(ps.getUrl(), compress));
		}
		return has;
	}
	
	public PlaylistWrapper getSinglePlaylist(PlaylistRequest req, BrandEnum brand) {
		Playlist pl = playlistService.getOnlinePlaylist(req.getPid(), brand);
		if (null == pl)
			return null;
		PlaylistWrapper wp = PlaylistWrapper.of(pl);
		// 专辑图片
		wp.setPics(getPlaylistPics(playlistPicsService.getPics(req.getPid()), brand));
		boolean isCollectPlaylist = false;
		// playabc 才有专辑的收藏
		if (brand == BrandEnum.playabc) {
			if (StringTools.isNotEmpty(req.getUid())) {
				isCollectPlaylist = userCollectService.isCollect(req.getUid(), req.getPid());
			}
			wp.setIsCollect(isCollectPlaylist);
		}
		// 获取下一个需要播放的视频
		if (req.getWithNextVideo()) {
			wp.setVideo(playlistVideoProxy.getNextPlayVideoForHistory(req.getUid(), pl.getPid(), pl.getWid(), brand));
		}
		return wp;
	}

	public List<PlaylistWrapper> getMultiPlaylist(PlaylistRequest req, BrandEnum brand) {
		List<Playlist> playlistArray = playlistService.getOnlinePlaylist(req.getPids(), brand);
		if (ArrayMapTools.isEmpty(playlistArray))
			return null;
		List<String> collectPlaylist = null;
		if (brand == BrandEnum.playabc) { // 获取已经收藏的专辑
			if (null == req.getIsCollect() && StringTools.isNotEmptyAndBlank(req.getUid()))
				collectPlaylist = userCollectService.getExistCollect(req.getUid(), req.getPids());
			if (null == collectPlaylist)
				collectPlaylist = Lists.newArrayList();
		}
		// 专辑图片
		Map<String, List<PlaylistPics>> pid2Pics = playlistPicsService.getPicsHas(req.getPids());
		
		// 下一个需要播放的视频
		Map<String, VideoWrapper> pid2VideoCard = null;
		if (req.getWithNextVideo()) {
			NextPlayVideoRequest nextRequest = NextPlayVideoRequest.of(req.getUid(), req.getSuid(), playlistArray);
			nextRequest.setIsSpecial(req.getIsSpecial()).setIsEverday(req.getIsEverday());
			pid2VideoCard = playlistVideoProxy.getNextPlayVideoForHistory(nextRequest);
		} else
			pid2VideoCard = Maps.newHashMap();

		List<PlaylistWrapper> wrappers = Lists.newArrayList();
		PlaylistWrapper wp = null;
		for (Playlist pl : playlistArray) {
			wp = PlaylistWrapper.of(pl);
			wp.setPics(this.getPlaylistPics(pid2Pics.get(pl.getPid()), brand));
			if (null != req.getIsCollect()) {
				wp.setIsCollect(req.getIsCollect());
			} else if (null != collectPlaylist) {
				wp.setIsCollect(collectPlaylist.contains(pl.getPid()));
			}
			if (null != req.getIsRecomm()) {
				wp.setIsRecomm(req.getIsRecomm());
			}
			wp.setVideo(pid2VideoCard.get(pl.getPid()));
			wrappers.add(wp);
		}
		return wrappers;
	}
	
	public Map<String, PlaylistWrapper> getMultiPlaylistHas(PlaylistRequest req, BrandEnum brand) {
		List<PlaylistWrapper> playlists = this.getMultiPlaylist(req, brand);
		if (ArrayMapTools.isEmpty(playlists))
			return Maps.newHashMap();
		Map<String, PlaylistWrapper> pid2Instance = Maps.newLinkedHashMap();
		playlists.forEach(it -> pid2Instance.put(it.getPid(), it));
		return pid2Instance;
	}
	
	public List<ItemCard> getMultiPlaylistCards(PlaylistRequest req, BrandEnum brand) {
		List<PlaylistWrapper> wrappers = this.getMultiPlaylist(req, brand);
		if (null == wrappers)
			return null;
		return wrappers.stream().map(ItemCard::of).collect(Collectors.toList());
	}
	
	public Map<String, ItemCard> getMultiPlaylistCardHas(PlaylistRequest req, BrandEnum brand) {
		List<ItemCard> cards = this.getMultiPlaylistCards(req, brand);
		if (ArrayMapTools.isEmpty(cards))
			return Maps.newHashMap();
		Map<String, ItemCard> pid2Card = Maps.newLinkedHashMap();
		cards.forEach(it-> pid2Card.put(it.getPlaylist().getPid(), it));
		return pid2Card;
	}
}
